"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .outstandingbalancebycustomer import (
    OutstandingBalanceByCustomer,
    OutstandingBalanceByCustomerTypedDict,
)
from apideck_unify.types import BaseModel
from datetime import date, datetime
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class AgedDebtorsTypedDict(TypedDict):
    report_generated_at: NotRequired[datetime]
    r"""The exact date and time the report was generated."""
    report_as_of_date: NotRequired[date]
    r"""The cutoff date for transactions included in the report."""
    period_count: NotRequired[int]
    r"""Number of aging periods shown in the report."""
    period_length: NotRequired[int]
    r"""Length of each aging period in days."""
    outstanding_balances: NotRequired[List[OutstandingBalanceByCustomerTypedDict]]


class AgedDebtors(BaseModel):
    report_generated_at: Optional[datetime] = None
    r"""The exact date and time the report was generated."""

    report_as_of_date: Optional[date] = None
    r"""The cutoff date for transactions included in the report."""

    period_count: Optional[int] = 4
    r"""Number of aging periods shown in the report."""

    period_length: Optional[int] = 30
    r"""Length of each aging period in days."""

    outstanding_balances: Optional[List[OutstandingBalanceByCustomer]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .currency import Currency
from .customfield import CustomField, CustomFieldTypedDict
from .custommappings import CustomMappings, CustomMappingsTypedDict
from .passthroughbody import PassThroughBody, PassThroughBodyTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import date, datetime
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OpportunityTypedDict(TypedDict):
    title: str
    r"""The title or name of the opportunity."""
    primary_contact_id: Nullable[str]
    r"""The unique identifier of the primary contact associated with the opportunity."""
    id: NotRequired[str]
    r"""A unique identifier for the opportunity."""
    description: NotRequired[Nullable[str]]
    r"""A description of the opportunity."""
    type: NotRequired[Nullable[str]]
    r"""The type of the opportunity"""
    monetary_amount: NotRequired[Nullable[float]]
    r"""The monetary value associated with the opportunity"""
    currency: NotRequired[Nullable[Currency]]
    r"""Indicates the associated currency for an amount of money. Values correspond to [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)."""
    win_probability: NotRequired[Nullable[float]]
    r"""The probability of winning the opportunity, expressed as a percentage."""
    expected_revenue: NotRequired[Nullable[float]]
    r"""The expected revenue from the opportunity"""
    close_date: NotRequired[Nullable[date]]
    r"""The actual closing date for the opportunity. If close_date is null, the opportunity is not closed yet."""
    loss_reason_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the reason why the opportunity was lost."""
    loss_reason: NotRequired[Nullable[str]]
    r"""The reason why the opportunity was lost."""
    won_reason_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the reason why the opportunity was won."""
    won_reason: NotRequired[Nullable[str]]
    r"""The reason why the opportunity was won."""
    pipeline_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the pipeline associated with the opportunity"""
    pipeline_stage_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the stage in the pipeline associated with the opportunity."""
    source_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the source of the opportunity."""
    lead_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the lead associated with the opportunity."""
    lead_source: NotRequired[Nullable[str]]
    r"""The source of the lead associated with the opportunity."""
    contact_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the contact associated with the opportunity."""
    contact_ids: NotRequired[List[str]]
    r"""An array of unique identifiers of all contacts associated with the opportunity."""
    company_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the company associated with the opportunity."""
    company_name: NotRequired[Nullable[str]]
    r"""The name of the company associated with the opportunity."""
    owner_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the user who owns the opportunity."""
    priority: NotRequired[Nullable[str]]
    r"""The priority level of the opportunity."""
    status: NotRequired[Nullable[str]]
    r"""The current status of the opportunity."""
    status_id: NotRequired[Nullable[str]]
    r"""The unique identifier of the current status of the opportunity."""
    tags: NotRequired[Nullable[List[str]]]
    interaction_count: NotRequired[Nullable[float]]
    r"""The number of interactions with the opportunity."""
    custom_fields: NotRequired[List[CustomFieldTypedDict]]
    stage_last_changed_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the stage of the opportunity was last changed."""
    last_activity_at: NotRequired[Nullable[str]]
    r"""The date and time of the last activity associated with the opportunity."""
    deleted: NotRequired[bool]
    r"""Indicates whether the opportunity has been deleted."""
    date_stage_changed: NotRequired[Nullable[datetime]]
    r"""The date and time when the stage of the opportunity was last changed."""
    date_last_contacted: NotRequired[Nullable[datetime]]
    r"""The date and time when the opportunity was last contacted."""
    date_lead_created: NotRequired[Nullable[datetime]]
    r"""The date and time when the lead associated with the opportunity was created."""
    custom_mappings: NotRequired[Nullable[CustomMappingsTypedDict]]
    r"""When custom mappings are configured on the resource, the result is included here."""
    updated_by: NotRequired[Nullable[str]]
    r"""The unique identifier of the user who last updated the opportunity."""
    created_by: NotRequired[Nullable[str]]
    r"""The unique identifier of the user who created the opportunity."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the opportunity was last updated."""
    created_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the opportunity was created."""
    pass_through: NotRequired[List[PassThroughBodyTypedDict]]
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""


class Opportunity(BaseModel):
    title: str
    r"""The title or name of the opportunity."""

    primary_contact_id: Nullable[str]
    r"""The unique identifier of the primary contact associated with the opportunity."""

    id: Optional[str] = None
    r"""A unique identifier for the opportunity."""

    description: OptionalNullable[str] = UNSET
    r"""A description of the opportunity."""

    type: OptionalNullable[str] = UNSET
    r"""The type of the opportunity"""

    monetary_amount: OptionalNullable[float] = UNSET
    r"""The monetary value associated with the opportunity"""

    currency: OptionalNullable[Currency] = UNSET
    r"""Indicates the associated currency for an amount of money. Values correspond to [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)."""

    win_probability: OptionalNullable[float] = UNSET
    r"""The probability of winning the opportunity, expressed as a percentage."""

    expected_revenue: OptionalNullable[float] = UNSET
    r"""The expected revenue from the opportunity"""

    close_date: OptionalNullable[date] = UNSET
    r"""The actual closing date for the opportunity. If close_date is null, the opportunity is not closed yet."""

    loss_reason_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the reason why the opportunity was lost."""

    loss_reason: OptionalNullable[str] = UNSET
    r"""The reason why the opportunity was lost."""

    won_reason_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the reason why the opportunity was won."""

    won_reason: OptionalNullable[str] = UNSET
    r"""The reason why the opportunity was won."""

    pipeline_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the pipeline associated with the opportunity"""

    pipeline_stage_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the stage in the pipeline associated with the opportunity."""

    source_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the source of the opportunity."""

    lead_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the lead associated with the opportunity."""

    lead_source: OptionalNullable[str] = UNSET
    r"""The source of the lead associated with the opportunity."""

    contact_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the contact associated with the opportunity."""

    contact_ids: Optional[List[str]] = None
    r"""An array of unique identifiers of all contacts associated with the opportunity."""

    company_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the company associated with the opportunity."""

    company_name: OptionalNullable[str] = UNSET
    r"""The name of the company associated with the opportunity."""

    owner_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the user who owns the opportunity."""

    priority: OptionalNullable[str] = UNSET
    r"""The priority level of the opportunity."""

    status: OptionalNullable[str] = UNSET
    r"""The current status of the opportunity."""

    status_id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the current status of the opportunity."""

    tags: OptionalNullable[List[str]] = UNSET

    interaction_count: OptionalNullable[float] = UNSET
    r"""The number of interactions with the opportunity."""

    custom_fields: Optional[List[CustomField]] = None

    stage_last_changed_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the stage of the opportunity was last changed."""

    last_activity_at: OptionalNullable[str] = UNSET
    r"""The date and time of the last activity associated with the opportunity."""

    deleted: Optional[bool] = None
    r"""Indicates whether the opportunity has been deleted."""

    date_stage_changed: OptionalNullable[datetime] = UNSET
    r"""The date and time when the stage of the opportunity was last changed."""

    date_last_contacted: OptionalNullable[datetime] = UNSET
    r"""The date and time when the opportunity was last contacted."""

    date_lead_created: OptionalNullable[datetime] = UNSET
    r"""The date and time when the lead associated with the opportunity was created."""

    custom_mappings: OptionalNullable[CustomMappings] = UNSET
    r"""When custom mappings are configured on the resource, the result is included here."""

    updated_by: OptionalNullable[str] = UNSET
    r"""The unique identifier of the user who last updated the opportunity."""

    created_by: OptionalNullable[str] = UNSET
    r"""The unique identifier of the user who created the opportunity."""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the opportunity was last updated."""

    created_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the opportunity was created."""

    pass_through: Optional[List[PassThroughBody]] = None
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "description",
            "type",
            "monetary_amount",
            "currency",
            "win_probability",
            "expected_revenue",
            "close_date",
            "loss_reason_id",
            "loss_reason",
            "won_reason_id",
            "won_reason",
            "pipeline_id",
            "pipeline_stage_id",
            "source_id",
            "lead_id",
            "lead_source",
            "contact_id",
            "contact_ids",
            "company_id",
            "company_name",
            "owner_id",
            "priority",
            "status",
            "status_id",
            "tags",
            "interaction_count",
            "custom_fields",
            "stage_last_changed_at",
            "last_activity_at",
            "deleted",
            "date_stage_changed",
            "date_last_contacted",
            "date_lead_created",
            "custom_mappings",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
            "pass_through",
        ]
        nullable_fields = [
            "primary_contact_id",
            "description",
            "type",
            "monetary_amount",
            "currency",
            "win_probability",
            "expected_revenue",
            "close_date",
            "loss_reason_id",
            "loss_reason",
            "won_reason_id",
            "won_reason",
            "pipeline_id",
            "pipeline_stage_id",
            "source_id",
            "lead_id",
            "lead_source",
            "contact_id",
            "company_id",
            "company_name",
            "owner_id",
            "priority",
            "status",
            "status_id",
            "tags",
            "interaction_count",
            "stage_last_changed_at",
            "last_activity_at",
            "date_stage_changed",
            "date_last_contacted",
            "date_lead_created",
            "custom_mappings",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .custommappings import CustomMappings, CustomMappingsTypedDict
from .linkedfolder import LinkedFolder, LinkedFolderTypedDict
from .owner import Owner, OwnerTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import datetime
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class FolderTypedDict(TypedDict):
    name: str
    r"""The name of the folder"""
    parent_folders: List[LinkedFolderTypedDict]
    r"""The parent folders of the file, starting from the root"""
    id: NotRequired[str]
    r"""A unique identifier for an object."""
    description: NotRequired[Nullable[str]]
    r"""Optional description of the folder"""
    path: NotRequired[Nullable[str]]
    r"""The full path of the folder (includes the folder name)"""
    size: NotRequired[Nullable[int]]
    r"""The size of the folder in bytes"""
    owner: NotRequired[OwnerTypedDict]
    parent_folders_complete: NotRequired[bool]
    r"""Whether the list of parent folder is complete. Some connectors only return the direct parent of a folder"""
    custom_mappings: NotRequired[Nullable[CustomMappingsTypedDict]]
    r"""When custom mappings are configured on the resource, the result is included here."""
    updated_by: NotRequired[Nullable[str]]
    r"""The user who last updated the object."""
    created_by: NotRequired[Nullable[str]]
    r"""The user who created the object."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was last updated."""
    created_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was created."""


class Folder(BaseModel):
    name: str
    r"""The name of the folder"""

    parent_folders: List[LinkedFolder]
    r"""The parent folders of the file, starting from the root"""

    id: Optional[str] = None
    r"""A unique identifier for an object."""

    description: OptionalNullable[str] = UNSET
    r"""Optional description of the folder"""

    path: OptionalNullable[str] = UNSET
    r"""The full path of the folder (includes the folder name)"""

    size: OptionalNullable[int] = UNSET
    r"""The size of the folder in bytes"""

    owner: Optional[Owner] = None

    parent_folders_complete: Optional[bool] = None
    r"""Whether the list of parent folder is complete. Some connectors only return the direct parent of a folder"""

    custom_mappings: OptionalNullable[CustomMappings] = UNSET
    r"""When custom mappings are configured on the resource, the result is included here."""

    updated_by: OptionalNullable[str] = UNSET
    r"""The user who last updated the object."""

    created_by: OptionalNullable[str] = UNSET
    r"""The user who created the object."""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was last updated."""

    created_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was created."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "description",
            "path",
            "size",
            "owner",
            "parent_folders_complete",
            "custom_mappings",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
        ]
        nullable_fields = [
            "description",
            "path",
            "size",
            "custom_mappings",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .custommappings import CustomMappings, CustomMappingsTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Optional
from typing_extensions import NotRequired, TypedDict


class IncomeTypedDict(TypedDict):
    total: Nullable[float]
    r"""Total income"""
    records: Any


class Income(BaseModel):
    total: Nullable[float]
    r"""Total income"""

    records: Any

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["total"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ExpensesModelTypedDict(TypedDict):
    total: Nullable[float]
    r"""Total expense"""
    records: Any


class ExpensesModel(BaseModel):
    total: Nullable[float]
    r"""Total expense"""

    records: Any

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["total"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class NetIncomeTypedDict(TypedDict):
    total: Nullable[float]
    r"""Total net income"""
    records: Any


class NetIncome(BaseModel):
    total: Nullable[float]
    r"""Total net income"""

    records: Any

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["total"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class NetOperatingIncomeTypedDict(TypedDict):
    total: Nullable[float]
    r"""Total net operating income"""
    records: Any


class NetOperatingIncome(BaseModel):
    total: Nullable[float]
    r"""Total net operating income"""

    records: Any

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["total"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GrossProfitTypedDict(TypedDict):
    total: Nullable[float]
    r"""Total gross profit"""
    records: Any


class GrossProfit(BaseModel):
    total: Nullable[float]
    r"""Total gross profit"""

    records: Any

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["total"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ProfitAndLossTypedDict(TypedDict):
    report_name: str
    r"""The name of the report"""
    currency: str
    income: IncomeTypedDict
    expenses: ExpensesModelTypedDict
    id: NotRequired[str]
    r"""A unique identifier for an object."""
    start_date: NotRequired[str]
    r"""The start date of the report"""
    end_date: NotRequired[str]
    r"""The start date of the report"""
    customer_id: NotRequired[str]
    r"""Customer id"""
    net_income: NotRequired[Nullable[NetIncomeTypedDict]]
    net_operating_income: NotRequired[Nullable[NetOperatingIncomeTypedDict]]
    gross_profit: NotRequired[Nullable[GrossProfitTypedDict]]
    custom_mappings: NotRequired[Nullable[CustomMappingsTypedDict]]
    r"""When custom mappings are configured on the resource, the result is included here."""


class ProfitAndLoss(BaseModel):
    report_name: str
    r"""The name of the report"""

    currency: str

    income: Income

    expenses: ExpensesModel

    id: Optional[str] = None
    r"""A unique identifier for an object."""

    start_date: Optional[str] = None
    r"""The start date of the report"""

    end_date: Optional[str] = None
    r"""The start date of the report"""

    customer_id: Optional[str] = None
    r"""Customer id"""

    net_income: OptionalNullable[NetIncome] = UNSET

    net_operating_income: OptionalNullable[NetOperatingIncome] = UNSET

    gross_profit: OptionalNullable[GrossProfit] = UNSET

    custom_mappings: OptionalNullable[CustomMappings] = UNSET
    r"""When custom mappings are configured on the resource, the result is included here."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "start_date",
            "end_date",
            "customer_id",
            "net_income",
            "net_operating_income",
            "gross_profit",
            "custom_mappings",
        ]
        nullable_fields = [
            "net_income",
            "net_operating_income",
            "gross_profit",
            "custom_mappings",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .simpleformfieldoption import SimpleFormFieldOption, SimpleFormFieldOptionTypedDict
from apideck_unify.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class FormFieldOptionGroupTypedDict(TypedDict):
    id: NotRequired[str]
    label: NotRequired[str]
    options: NotRequired[List[SimpleFormFieldOptionTypedDict]]


class FormFieldOptionGroup(BaseModel):
    id: Optional[str] = None

    label: Optional[str] = None

    options: Optional[List[SimpleFormFieldOption]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PaymentType(str, Enum):
    r"""Type of payment"""

    ACCOUNTS_RECEIVABLE = "accounts_receivable"
    ACCOUNTS_PAYABLE = "accounts_payable"
    ACCOUNTS_RECEIVABLE_CREDIT = "accounts_receivable_credit"
    ACCOUNTS_PAYABLE_CREDIT = "accounts_payable_credit"
    ACCOUNTS_RECEIVABLE_OVERPAYMENT = "accounts_receivable_overpayment"
    ACCOUNTS_PAYABLE_OVERPAYMENT = "accounts_payable_overpayment"
    ACCOUNTS_RECEIVABLE_PREPAYMENT = "accounts_receivable_prepayment"
    ACCOUNTS_PAYABLE_PREPAYMENT = "accounts_payable_prepayment"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from .customfield import CustomField, CustomFieldTypedDict
from .custommappings import CustomMappings, CustomMappingsTypedDict
from .email import Email, EmailTypedDict
from .passthroughbody import PassThroughBody, PassThroughBodyTypedDict
from .phonenumber import PhoneNumber, PhoneNumberTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import date, datetime
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ApplicantType(str, Enum):
    r"""The type of website"""

    PRIMARY = "primary"
    SECONDARY = "secondary"
    WORK = "work"
    PERSONAL = "personal"
    OTHER = "other"


class WebsitesTypedDict(TypedDict):
    url: str
    r"""The website URL"""
    id: NotRequired[Nullable[str]]
    r"""Unique identifier for the website"""
    type: NotRequired[Nullable[ApplicantType]]
    r"""The type of website"""


class Websites(BaseModel):
    url: str
    r"""The website URL"""

    id: OptionalNullable[str] = UNSET
    r"""Unique identifier for the website"""

    type: OptionalNullable[ApplicantType] = UNSET
    r"""The type of website"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "type"]
        nullable_fields = ["id", "type"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class SocialLinksTypedDict(TypedDict):
    url: str
    r"""URL of the social link, e.g. https://www.twitter.com/apideck"""
    id: NotRequired[Nullable[str]]
    r"""Unique identifier of the social link"""
    type: NotRequired[Nullable[str]]
    r"""Type of the social link, e.g. twitter"""


class SocialLinks(BaseModel):
    url: str
    r"""URL of the social link, e.g. https://www.twitter.com/apideck"""

    id: OptionalNullable[str] = UNSET
    r"""Unique identifier of the social link"""

    type: OptionalNullable[str] = UNSET
    r"""Type of the social link, e.g. twitter"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "type"]
        nullable_fields = ["id", "type"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ApplicantTypedDict(TypedDict):
    id: NotRequired[str]
    r"""A unique identifier for an object."""
    name: NotRequired[str]
    r"""The name of an applicant."""
    first_name: NotRequired[Nullable[str]]
    r"""The first name of the person."""
    last_name: NotRequired[Nullable[str]]
    r"""The last name of the person."""
    middle_name: NotRequired[Nullable[str]]
    r"""Middle name of the person."""
    initials: NotRequired[Nullable[str]]
    r"""The initials of the person, usually derived from their first, middle, and last names."""
    birthday: NotRequired[Nullable[date]]
    r"""The date of birth of the person."""
    cover_letter: NotRequired[str]
    job_url: NotRequired[Nullable[str]]
    photo_url: NotRequired[Nullable[str]]
    r"""The URL of the photo of a person."""
    headline: NotRequired[str]
    r"""Typically a list of previous companies where the contact has worked or schools that the contact has attended"""
    title: NotRequired[Nullable[str]]
    r"""The job title of the person."""
    emails: NotRequired[List[EmailTypedDict]]
    custom_fields: NotRequired[List[CustomFieldTypedDict]]
    phone_numbers: NotRequired[List[PhoneNumberTypedDict]]
    addresses: NotRequired[List[AddressTypedDict]]
    websites: NotRequired[List[WebsitesTypedDict]]
    social_links: NotRequired[List[SocialLinksTypedDict]]
    stage_id: NotRequired[str]
    recruiter_id: NotRequired[str]
    coordinator_id: NotRequired[str]
    application_ids: NotRequired[Nullable[List[str]]]
    applications: NotRequired[Nullable[List[str]]]
    followers: NotRequired[Nullable[List[str]]]
    sources: NotRequired[Nullable[List[str]]]
    source_id: NotRequired[str]
    confidential: NotRequired[bool]
    anonymized: NotRequired[bool]
    tags: NotRequired[Nullable[List[str]]]
    archived: NotRequired[Nullable[bool]]
    last_interaction_at: NotRequired[Nullable[datetime]]
    owner_id: NotRequired[Nullable[str]]
    sourced_by: NotRequired[Nullable[str]]
    cv_url: NotRequired[str]
    record_url: NotRequired[Nullable[str]]
    rejected_at: NotRequired[Nullable[datetime]]
    custom_mappings: NotRequired[Nullable[CustomMappingsTypedDict]]
    r"""When custom mappings are configured on the resource, the result is included here."""
    deleted: NotRequired[Nullable[bool]]
    r"""Flag to indicate if the object is deleted."""
    deleted_by: NotRequired[Nullable[str]]
    r"""The user who deleted the object."""
    deleted_at: NotRequired[Nullable[datetime]]
    r"""The time at which the object was deleted."""
    updated_by: NotRequired[Nullable[str]]
    r"""The user who last updated the object."""
    created_by: NotRequired[Nullable[str]]
    r"""The user who created the object."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was last updated."""
    created_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was created."""
    pass_through: NotRequired[List[PassThroughBodyTypedDict]]
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""


class Applicant(BaseModel):
    id: Optional[str] = None
    r"""A unique identifier for an object."""

    name: Optional[str] = None
    r"""The name of an applicant."""

    first_name: OptionalNullable[str] = UNSET
    r"""The first name of the person."""

    last_name: OptionalNullable[str] = UNSET
    r"""The last name of the person."""

    middle_name: OptionalNullable[str] = UNSET
    r"""Middle name of the person."""

    initials: OptionalNullable[str] = UNSET
    r"""The initials of the person, usually derived from their first, middle, and last names."""

    birthday: OptionalNullable[date] = UNSET
    r"""The date of birth of the person."""

    cover_letter: Optional[str] = None

    job_url: OptionalNullable[str] = UNSET

    photo_url: OptionalNullable[str] = UNSET
    r"""The URL of the photo of a person."""

    headline: Optional[str] = None
    r"""Typically a list of previous companies where the contact has worked or schools that the contact has attended"""

    title: OptionalNullable[str] = UNSET
    r"""The job title of the person."""

    emails: Optional[List[Email]] = None

    custom_fields: Optional[List[CustomField]] = None

    phone_numbers: Optional[List[PhoneNumber]] = None

    addresses: Optional[List[Address]] = None

    websites: Optional[List[Websites]] = None

    social_links: Optional[List[SocialLinks]] = None

    stage_id: Optional[str] = None

    recruiter_id: Optional[str] = None

    coordinator_id: Optional[str] = None

    application_ids: OptionalNullable[List[str]] = UNSET

    applications: OptionalNullable[List[str]] = UNSET

    followers: OptionalNullable[List[str]] = UNSET

    sources: OptionalNullable[List[str]] = UNSET

    source_id: Optional[str] = None

    confidential: Optional[bool] = None

    anonymized: Optional[bool] = None

    tags: OptionalNullable[List[str]] = UNSET

    archived: OptionalNullable[bool] = UNSET

    last_interaction_at: OptionalNullable[datetime] = UNSET

    owner_id: OptionalNullable[str] = UNSET

    sourced_by: OptionalNullable[str] = UNSET

    cv_url: Optional[str] = None

    record_url: OptionalNullable[str] = UNSET

    rejected_at: OptionalNullable[datetime] = UNSET

    custom_mappings: OptionalNullable[CustomMappings] = UNSET
    r"""When custom mappings are configured on the resource, the result is included here."""

    deleted: OptionalNullable[bool] = UNSET
    r"""Flag to indicate if the object is deleted."""

    deleted_by: OptionalNullable[str] = UNSET
    r"""The user who deleted the object."""

    deleted_at: OptionalNullable[datetime] = UNSET
    r"""The time at which the object was deleted."""

    updated_by: OptionalNullable[str] = UNSET
    r"""The user who last updated the object."""

    created_by: OptionalNullable[str] = UNSET
    r"""The user who created the object."""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was last updated."""

    created_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was created."""

    pass_through: Optional[List[PassThroughBody]] = None
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "name",
            "first_name",
            "last_name",
            "middle_name",
            "initials",
            "birthday",
            "cover_letter",
            "job_url",
            "photo_url",
            "headline",
            "title",
            "emails",
            "custom_fields",
            "phone_numbers",
            "addresses",
            "websites",
            "social_links",
            "stage_id",
            "recruiter_id",
            "coordinator_id",
            "application_ids",
            "applications",
            "followers",
            "sources",
            "source_id",
            "confidential",
            "anonymized",
            "tags",
            "archived",
            "last_interaction_at",
            "owner_id",
            "sourced_by",
            "cv_url",
            "record_url",
            "rejected_at",
            "custom_mappings",
            "deleted",
            "deleted_by",
            "deleted_at",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
            "pass_through",
        ]
        nullable_fields = [
            "first_name",
            "last_name",
            "middle_name",
            "initials",
            "birthday",
            "job_url",
            "photo_url",
            "title",
            "application_ids",
            "applications",
            "followers",
            "sources",
            "tags",
            "archived",
            "last_interaction_at",
            "owner_id",
            "sourced_by",
            "record_url",
            "rejected_at",
            "custom_mappings",
            "deleted",
            "deleted_by",
            "deleted_at",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ApplicantInputTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of an applicant."""
    first_name: NotRequired[Nullable[str]]
    r"""The first name of the person."""
    last_name: NotRequired[Nullable[str]]
    r"""The last name of the person."""
    middle_name: NotRequired[Nullable[str]]
    r"""Middle name of the person."""
    initials: NotRequired[Nullable[str]]
    r"""The initials of the person, usually derived from their first, middle, and last names."""
    birthday: NotRequired[Nullable[date]]
    r"""The date of birth of the person."""
    cover_letter: NotRequired[str]
    photo_url: NotRequired[Nullable[str]]
    r"""The URL of the photo of a person."""
    headline: NotRequired[str]
    r"""Typically a list of previous companies where the contact has worked or schools that the contact has attended"""
    title: NotRequired[Nullable[str]]
    r"""The job title of the person."""
    emails: NotRequired[List[EmailTypedDict]]
    custom_fields: NotRequired[List[CustomFieldTypedDict]]
    phone_numbers: NotRequired[List[PhoneNumberTypedDict]]
    addresses: NotRequired[List[AddressTypedDict]]
    websites: NotRequired[List[WebsitesTypedDict]]
    social_links: NotRequired[List[SocialLinksTypedDict]]
    stage_id: NotRequired[str]
    recruiter_id: NotRequired[str]
    coordinator_id: NotRequired[str]
    application_ids: NotRequired[Nullable[List[str]]]
    applications: NotRequired[Nullable[List[str]]]
    followers: NotRequired[Nullable[List[str]]]
    sources: NotRequired[Nullable[List[str]]]
    confidential: NotRequired[bool]
    anonymized: NotRequired[bool]
    tags: NotRequired[Nullable[List[str]]]
    archived: NotRequired[Nullable[bool]]
    owner_id: NotRequired[Nullable[str]]
    record_url: NotRequired[Nullable[str]]
    deleted: NotRequired[Nullable[bool]]
    r"""Flag to indicate if the object is deleted."""
    pass_through: NotRequired[List[PassThroughBodyTypedDict]]
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""


class ApplicantInput(BaseModel):
    name: Optional[str] = None
    r"""The name of an applicant."""

    first_name: OptionalNullable[str] = UNSET
    r"""The first name of the person."""

    last_name: OptionalNullable[str] = UNSET
    r"""The last name of the person."""

    middle_name: OptionalNullable[str] = UNSET
    r"""Middle name of the person."""

    initials: OptionalNullable[str] = UNSET
    r"""The initials of the person, usually derived from their first, middle, and last names."""

    birthday: OptionalNullable[date] = UNSET
    r"""The date of birth of the person."""

    cover_letter: Optional[str] = None

    photo_url: OptionalNullable[str] = UNSET
    r"""The URL of the photo of a person."""

    headline: Optional[str] = None
    r"""Typically a list of previous companies where the contact has worked or schools that the contact has attended"""

    title: OptionalNullable[str] = UNSET
    r"""The job title of the person."""

    emails: Optional[List[Email]] = None

    custom_fields: Optional[List[CustomField]] = None

    phone_numbers: Optional[List[PhoneNumber]] = None

    addresses: Optional[List[Address]] = None

    websites: Optional[List[Websites]] = None

    social_links: Optional[List[SocialLinks]] = None

    stage_id: Optional[str] = None

    recruiter_id: Optional[str] = None

    coordinator_id: Optional[str] = None

    application_ids: OptionalNullable[List[str]] = UNSET

    applications: OptionalNullable[List[str]] = UNSET

    followers: OptionalNullable[List[str]] = UNSET

    sources: OptionalNullable[List[str]] = UNSET

    confidential: Optional[bool] = None

    anonymized: Optional[bool] = None

    tags: OptionalNullable[List[str]] = UNSET

    archived: OptionalNullable[bool] = UNSET

    owner_id: OptionalNullable[str] = UNSET

    record_url: OptionalNullable[str] = UNSET

    deleted: OptionalNullable[bool] = UNSET
    r"""Flag to indicate if the object is deleted."""

    pass_through: Optional[List[PassThroughBody]] = None
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "name",
            "first_name",
            "last_name",
            "middle_name",
            "initials",
            "birthday",
            "cover_letter",
            "photo_url",
            "headline",
            "title",
            "emails",
            "custom_fields",
            "phone_numbers",
            "addresses",
            "websites",
            "social_links",
            "stage_id",
            "recruiter_id",
            "coordinator_id",
            "application_ids",
            "applications",
            "followers",
            "sources",
            "confidential",
            "anonymized",
            "tags",
            "archived",
            "owner_id",
            "record_url",
            "deleted",
            "pass_through",
        ]
        nullable_fields = [
            "first_name",
            "last_name",
            "middle_name",
            "initials",
            "birthday",
            "photo_url",
            "title",
            "application_ids",
            "applications",
            "followers",
            "sources",
            "tags",
            "archived",
            "owner_id",
            "record_url",
            "deleted",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .authtype import AuthType
from .connectionstate import ConnectionState
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class SettingsTypedDict(TypedDict):
    r"""Connection settings. Values will persist to `form_fields` with corresponding id"""


class Settings(BaseModel):
    r"""Connection settings. Values will persist to `form_fields` with corresponding id"""


class ConsumerConnectionTypedDict(TypedDict):
    id: NotRequired[str]
    name: NotRequired[str]
    icon: NotRequired[str]
    logo: NotRequired[str]
    website: NotRequired[str]
    tag_line: NotRequired[str]
    service_id: NotRequired[str]
    unified_api: NotRequired[str]
    consumer_id: NotRequired[str]
    auth_type: NotRequired[AuthType]
    r"""Type of authorization used by the connector"""
    enabled: NotRequired[bool]
    settings: NotRequired[Nullable[SettingsTypedDict]]
    r"""Connection settings. Values will persist to `form_fields` with corresponding id"""
    metadata: NotRequired[Nullable[Dict[str, Any]]]
    r"""Attach your own consumer specific metadata"""
    created_at: NotRequired[str]
    updated_at: NotRequired[Nullable[str]]
    state: NotRequired[ConnectionState]
    r"""[Connection state flow](#section/Connection-state)"""


class ConsumerConnection(BaseModel):
    id: Optional[str] = None

    name: Optional[str] = None

    icon: Optional[str] = None

    logo: Optional[str] = None

    website: Optional[str] = None

    tag_line: Optional[str] = None

    service_id: Optional[str] = None

    unified_api: Optional[str] = None

    consumer_id: Optional[str] = None

    auth_type: Optional[AuthType] = None
    r"""Type of authorization used by the connector"""

    enabled: Optional[bool] = None

    settings: OptionalNullable[Settings] = UNSET
    r"""Connection settings. Values will persist to `form_fields` with corresponding id"""

    metadata: OptionalNullable[Dict[str, Any]] = UNSET
    r"""Attach your own consumer specific metadata"""

    created_at: Optional[str] = None

    updated_at: OptionalNullable[str] = UNSET

    state: Optional[ConnectionState] = None
    r"""[Connection state flow](#section/Connection-state)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "name",
            "icon",
            "logo",
            "website",
            "tag_line",
            "service_id",
            "unified_api",
            "consumer_id",
            "auth_type",
            "enabled",
            "settings",
            "metadata",
            "created_at",
            "updated_at",
            "state",
        ]
        nullable_fields = ["settings", "metadata", "updated_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .consumerrequestcountsindaterangeresponse import (
    ConsumerRequestCountsInDateRangeResponse,
    ConsumerRequestCountsInDateRangeResponseTypedDict,
)
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .unexpectederrorresponse import (
    UnexpectedErrorResponse,
    UnexpectedErrorResponseTypedDict,
)
from apideck_unify.types import BaseModel
from apideck_unify.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    QueryParamMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class VaultConsumerRequestCountsAllGlobalsTypedDict(TypedDict):
    app_id: NotRequired[str]
    r"""The ID of your Unify application"""


class VaultConsumerRequestCountsAllGlobals(BaseModel):
    app_id: Annotated[
        Optional[str],
        pydantic.Field(alias="x-apideck-app-id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The ID of your Unify application"""


class VaultConsumerRequestCountsAllRequestTypedDict(TypedDict):
    consumer_id: str
    r"""ID of the consumer to return"""
    start_datetime: str
    r"""Scopes results to requests that happened after datetime"""
    end_datetime: str
    r"""Scopes results to requests that happened before datetime"""


class VaultConsumerRequestCountsAllRequest(BaseModel):
    consumer_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""ID of the consumer to return"""

    start_datetime: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""Scopes results to requests that happened after datetime"""

    end_datetime: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""Scopes results to requests that happened before datetime"""


class VaultConsumerRequestCountsAllResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    consumer_request_counts_in_date_range_response: NotRequired[
        ConsumerRequestCountsInDateRangeResponseTypedDict
    ]
    r"""Consumers Request Counts within Date Range"""
    unexpected_error_response: NotRequired[UnexpectedErrorResponseTypedDict]
    r"""Unexpected error"""


class VaultConsumerRequestCountsAllResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    consumer_request_counts_in_date_range_response: Optional[
        ConsumerRequestCountsInDateRangeResponse
    ] = None
    r"""Consumers Request Counts within Date Range"""

    unexpected_error_response: Optional[UnexpectedErrorResponse] = None
    r"""Unexpected error"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from apideck_unify.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LinkedParentCustomerTypedDict(TypedDict):
    r"""The parent customer this entity is linked to."""

    id: str
    r"""The parent ID of the customer this entity is linked to."""
    name: NotRequired[str]
    r"""The name of the parent customer."""


class LinkedParentCustomer(BaseModel):
    r"""The parent customer this entity is linked to."""

    id: str
    r"""The parent ID of the customer this entity is linked to."""

    name: Optional[str] = None
    r"""The name of the parent customer."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .connectorstatus import ConnectorStatus
from .unifiedapiid import UnifiedAPIID
from apideck_unify.types import BaseModel
from apideck_unify.utils import FieldMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorsFilterTypedDict(TypedDict):
    unified_api: NotRequired[UnifiedAPIID]
    r"""Name of Apideck Unified API"""
    status: NotRequired[ConnectorStatus]
    r"""Status of the connector. Connectors with status live or beta are callable."""


class ConnectorsFilter(BaseModel):
    unified_api: Annotated[Optional[UnifiedAPIID], FieldMetadata(query=True)] = None
    r"""Name of Apideck Unified API"""

    status: Annotated[Optional[ConnectorStatus], FieldMetadata(query=True)] = None
    r"""Status of the connector. Connectors with status live or beta are callable."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .links import Links, LinksTypedDict
from .meta import Meta, MetaTypedDict
from .unifiedfile import UnifiedFile, UnifiedFileTypedDict
from apideck_unify.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class GetFilesResponseTypedDict(TypedDict):
    r"""Files"""

    status_code: int
    r"""HTTP Response Status Code"""
    status: str
    r"""HTTP Response Status"""
    service: str
    r"""Apideck ID of service provider"""
    resource: str
    r"""Unified API resource name"""
    operation: str
    r"""Operation performed"""
    data: List[UnifiedFileTypedDict]
    meta: NotRequired[MetaTypedDict]
    r"""Response metadata"""
    links: NotRequired[LinksTypedDict]
    r"""Links to navigate to previous or next pages through the API"""


class GetFilesResponse(BaseModel):
    r"""Files"""

    status_code: int
    r"""HTTP Response Status Code"""

    status: str
    r"""HTTP Response Status"""

    service: str
    r"""Apideck ID of service provider"""

    resource: str
    r"""Unified API resource name"""

    operation: str
    r"""Operation performed"""

    data: List[UnifiedFile]

    meta: Optional[Meta] = None
    r"""Response metadata"""

    links: Optional[Links] = None
    r"""Links to navigate to previous or next pages through the API"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from apideck_unify.types import BaseModel
from apideck_unify.utils import FieldMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FilesFilterTypedDict(TypedDict):
    drive_id: NotRequired[str]
    r"""ID of the drive to filter on"""
    folder_id: NotRequired[str]
    r"""ID of the folder to filter on. The root folder has an alias \"root\" """
    shared: NotRequired[bool]
    r"""Only return files and folders that are shared"""


class FilesFilter(BaseModel):
    drive_id: Annotated[Optional[str], FieldMetadata(query=True)] = None
    r"""ID of the drive to filter on"""

    folder_id: Annotated[Optional[str], FieldMetadata(query=True)] = None
    r"""ID of the folder to filter on. The root folder has an alias \"root\" """

    shared: Annotated[Optional[bool], FieldMetadata(query=True)] = None
    r"""Only return files and folders that are shared"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sortdirection import SortDirection
from apideck_unify.types import BaseModel
from apideck_unify.utils import FieldMetadata
from enum import Enum
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PaymentsSortBy(str, Enum):
    r"""The field on which to sort the Payments"""

    UPDATED_AT = "updated_at"
    CREATED_AT = "created_at"


class PaymentsSortTypedDict(TypedDict):
    by: NotRequired[PaymentsSortBy]
    r"""The field on which to sort the Payments"""
    direction: NotRequired[SortDirection]
    r"""The direction in which to sort the results"""


class PaymentsSort(BaseModel):
    by: Annotated[Optional[PaymentsSortBy], FieldMetadata(query=True)] = None
    r"""The field on which to sort the Payments"""

    direction: Annotated[Optional[SortDirection], FieldMetadata(query=True)] = (
        SortDirection.ASC
    )
    r"""The direction in which to sort the results"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import datetime
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class TrackingItemTypedDict(TypedDict):
    r"""Represents the tracking information associated with an ecommerce order."""

    provider: Nullable[str]
    r"""The name or code of the carrier or shipping company that is handling the shipment."""
    number: Nullable[str]
    r"""The tracking number associated with the shipment, which can be used to track the progress of the delivery."""
    url: NotRequired[Nullable[str]]
    r"""The URL of the carrier's tracking page, which can be used to view detailed information about the shipment's progress."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was last updated."""


class TrackingItem(BaseModel):
    r"""Represents the tracking information associated with an ecommerce order."""

    provider: Nullable[str]
    r"""The name or code of the carrier or shipping company that is handling the shipment."""

    number: Nullable[str]
    r"""The tracking number associated with the shipment, which can be used to track the progress of the delivery."""

    url: OptionalNullable[str] = UNSET
    r"""The URL of the carrier's tracking page, which can be used to view detailed information about the shipment's progress."""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was last updated."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["url", "updated_at"]
        nullable_fields = ["provider", "number", "url", "updated_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
